This is a simple Repo

[![Tests](https://github.com/s4sarath/mycalc2/workflows/Tests/badge.svg)](https://github.com/s4sarath/mycalc2/actions?workflow=Tests)
[![codecov](https://codecov.io/gh/s4sarath/mycalc2/branch/main/graph/badge.svg)](https://codecov.io/gh/s4sarath/mycalc2)
![Release](https://github.com/s4sarath/mycalc2/workflows/Release/badge.svg)
[![PyPI](https://img.shields.io/pypi/v/mycalc2.svg)](https://pypi.org/project/mycalc2/)
[![Tag](https://img.shields.io/github/v/tag/s4sarath/mycalc2.svg?sort=semver)](https://github.com/s4sarath/mycalc2/tags)
[![release](https://img.shields.io/github/v/release/s4sarath/mycalc2.svg?sort=semver)](https://github.com/s4sarath/mycalc2/releases)
